@@ -2,7 +2,7 @@
 {-# LANGUAGE DeriveDataTypeable #-}
 {-# LANGUAGE PolyKinds          #-}
 {-# OPTIONS_HADDOCK not-home    #-}
-module Servant.API.Capture (Capture, CaptureAll) where
+module Servant.API.Capture (Capture, Capture', CaptureAll) where
 
 import           Data.Typeable (Typeable)
 import           GHC.TypeLits  (Symbol)
@@ -12,9 +12,11 @@ import           GHC.TypeLits  (Symbol)
 --
 -- >>>            -- GET /books/:isbn
 -- >>> type MyApi = "books" :> Capture "isbn" Text :> Get '[JSON] Book
-data Capture (sym :: Symbol) a
-    deriving (Typeable)
+type Capture = Capture' '[] -- todo
 
+-- | 'Capture' which can be modified. For example with 'Description'.
+data Capture' (mods :: [*]) (sym :: Symbol) (a :: *)
+    deriving (Typeable)
 
 -- | Capture all remaining values from the request path under a certain type
 -- @a@.
@@ -23,7 +25,7 @@ data Capture (sym :: Symbol) a
 --
 -- >>>            -- GET /src/*
 -- >>> type MyAPI = "src" :> CaptureAll "segments" Text :> Get '[JSON] SourceFile
-data CaptureAll (sym :: Symbol) a
+data CaptureAll (sym :: Symbol) (a :: *)
     deriving (Typeable)
 
 -- $setup
