@@ -14,9 +14,9 @@ import           Data.Typeable (Typeable)
 -- >>> -- GET /hello/world
 -- >>> -- returning a JSON encoded World value
 -- >>> type MyApi = "hello" :> "world" :> Get '[JSON] World
-data (path :: k) :> a
+data (path :: k) :> (a :: *)
     deriving (Typeable)
-infixr 9 :>
+infixr 4 :>
 
 -- $setup
 -- >>> import Servant.API
